@@ -1,13 +1,13 @@
 from . import utils
 from . import soup
-from .. import errors
-from ..topic import Topic
-from ..exercise import Exercise
-from ..task import Task
-from ..person import Person
-from ..node import Node
-from ..group import Group
-from ..errors import OpenTrainingError
+from ..core import errors
+from ..core.topic import Topic
+from ..core.exercise import Exercise
+from ..core.task import Task
+from ..core.person import Person
+from ..core.node import Node
+from ..core.group import Group
+from ..core.errors import OpenTrainingError
 
 from sphinx.util.docutils import SphinxDirective
 from sphinx.util.nodes import set_source_info
